@@ -15,7 +15,7 @@ function(numUpdates, thin = 1, overRelax = FALSE)
         ";BugsEmbed.overRelax := ", as.integer(overRelax),
         ";BugsEmbed.updates := ", numUpdates,
         ";BugsEmbed.Update")
-    .C("CmdInterpreter", command, nchar(command), integer(1), PACKAGE="BRugs")
+    .CmdInterpreter(command)
     if(getOption("BRugsVerbose")) 
         buffer()
 }
